@@ -14,11 +14,6 @@
 #include <QIntValidator>
 #include <QLineEdit>
 
-/**
- * @internal
- * Year selection widget.
- * @author Tim Gilman, Mirko Boehm, John Layt
- */
 class KDatePickerPrivateYearSelector : public QLineEdit
 {
     Q_OBJECT
@@ -26,7 +21,7 @@ class KDatePickerPrivateYearSelector : public QLineEdit
 public:
     explicit KDatePickerPrivateYearSelector(const QDate &currentDate, QWidget *parent = nullptr);
     int year();
-    void setYear(int year);
+    void setYear(const QDate &year);
 
 public Q_SLOTS:
     void yearEnteredSlot();
