@@ -1,7 +1,7 @@
+#include <QApplication>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
-#include <qapplication.h>
 
 #include <QDebug>
 #include <keditlistwidget.h>
@@ -9,7 +9,6 @@
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 
 #if 0
     KEditListWidget::CustomEditor editor(new KComboBox(true, 0));
